<?php
namespace App\Http\Controllers;

use App\Models\Cita;
use App\Models\Cliente;
use Carbon\Carbon;
use Illuminate\Http\Request;

class CalendarioController extends Controller
{
    public function mostrarCalendario(Request $request)
    {
        // Configurar Carbon en español
        Carbon::setLocale('es');

        // Obtener el número de semana desde la solicitud o usar la semana actual
        $semana = $request->get('semana', Carbon::now()->weekOfYear);

        // Calcular la fecha de inicio y fin de la semana
        $fechaInicioSemana = Carbon::now()->setISODate(Carbon::now()->year, $semana)->startOfWeek();
        $fechaFinSemana = Carbon::now()->setISODate(Carbon::now()->year, $semana)->endOfWeek();
        
        // Obtener la fecha de hoy
        $hoy = Carbon::now();
        
        // Obtener el número de semana actual
        $semanaActual = Carbon::now()->weekOfYear;

        // Obtener citas de la semana
        $citasSemana = Cita::whereBetween('fecha', [$fechaInicioSemana, $fechaFinSemana])
            ->orderBy('fecha')
            ->orderBy('hora')
            ->get();

        // Horas específicas desde 8 AM hasta 8 PM
        $horas = [
            '08:00:00','08:30:00', '09:00:00','09:30:00', '10:00:00','10:30:00', '11:00:00','11:30:00', '12:00:00','12:30:00',
            '13:00:00','13:30:00', '14:00:00','14:30:00', '15:00:00','15:30:00', '16:00:00','16:30:00', '17:00:00','17:30:00',
            '18:00:00','18:30:00', '19:00:00','19:30:00', '20:00:00'
        ];

        return view('calendario', compact('citasSemana', 'horas', 'semana', 'semanaActual', 'fechaInicioSemana', 'fechaFinSemana', 'hoy'));
    
    
    }


    public function destroy($id)
    {
        $cita = Cita::findOrFail($id);
        $cita->delete();
    
        return redirect()->route('calendario.mostrar')->with('success', 'Cita eliminada exitosamente.');
    }



}
