<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\Cita;
use App\Models\Cliente;
use App\Models\Servicio;
use Barryvdh\DomPDF\Facade\Pdf;
use Carbon\Carbon;
use Illuminate\Http\Request;

use App\Mail\CitaAgendada;
use Illuminate\Support\Facades\Mail;

class ControllerCita extends Controller
{
    /**
     * Display a listing of the resource.
     */

    public function index()
    {
        $data = Cita::with('cliente')
            ->whereNull('atendida')
            ->orWhere('atendida', '<>', 1)
            ->orderBy('fecha', 'asc') // Ordenar por fecha ascendente
            ->get();

        $clientes = Cliente::all();

        return view('cita.index', compact('data', 'clientes'));
    }


    public function indexAtendidas()
    {
        $dataAtendidas = Cita::with('cliente') // Cambiado a 'cliente' en lugar de 'clientes'
            ->where('atendida', 1)
            ->get();

        $clientes = Cliente::all(); // Cambiado a 'clientes' en lugar de 'iten'

        return view('cita.citasAtendidas', compact('dataAtendidas', 'clientes'));
    }



    public function showw($id_cliente)
    {
        $cliente = Cliente::find($id_cliente);
        $citasNoAtendidas = $cliente->citas()->where('atendida', 0)->get(); // Citas no atendidas
        $citasAtendidas = $cliente->citas()->where('atendida', 1)->get(); // Citas atendidas
        $citasCanceladas = $cliente->citas()->where('atendida', 2)->get(); // Citas canceladas (o el estado correspondiente)

        return view('citas.index', compact('cliente', 'citasNoAtendidas', 'citasAtendidas', 'citasCanceladas'));
    }


    public function create()
    {
        $clientes = Cliente::all(); // Obtener todos los clientes
        $servicios = Servicio::all(); // Obtener todos los servicios

        // Pasar ambas variables a la vista
        return view('cita.create', compact('clientes', 'servicios'));
    }


    public function store(Request $request)
    {
        // Validación de los datos del formulario
        $request->validate([
            'id_cliente' => 'required|exists:clientes,id_cliente', // Asegura que el id_cliente exista en la tabla clientes
            'id_servicio' => 'required|exists:servicios,id_servicio', // Asegura que el id_cliente exista en la tabla clientes
            'fecha' => 'required|date', // Asegura que la fecha sea una fecha válida
            'hora' => 'required', // Asegura que se haya seleccionado una hora
        ]);

        // Verificar si ya existe una cita para la misma fecha y hora
        $existingCita = Cita::where('fecha', $request->fecha)
            ->where('hora', $request->hora)
            ->exists();

        if ($existingCita) {
            // Redirigir a la vista de cita no exitosa
            return view('cita.noexitosa', [
                'fecha' => $request->fecha,
                'hora' => $request->hora,
            ]);
        }

        // Crear una nueva instancia de Cita y asignar valores
        $cita = new Cita();
        $cita->id_cliente = $request->id_cliente;
        $cita->id_servicio = $request->id_servicio;
        $cita->fecha = $request->fecha;
        $cita->hora = $request->hora;

        // Guardar la cita
        $cita->save();

        // Redirigir a la vista de confirmación con los datos de la cita
        return view('cita.exitosa', [
            'fecha' => $cita->fecha,
            'hora' => $cita->hora,
        ]);
    }
    /////////////////////////////////////////



    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $iten = Cliente::all();
        $item = Cita::findOrFail($id); // Asegúrate de usar findOrFail para manejar errores si no se encuentra la cita

        return view('cita.edit', compact('item', 'iten'));
    }


    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $item = Cita::find($id);
        $item->id_cliente = $request->id_cliente;
        $item->fecha = $request->fecha;
        $item->hora = $request->hora;
        $item->save();
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $item = Cita::find($id);
        $item->delete();

        return redirect()->route('Cita.index');
    }



    public function marcarComoAtendida(Request $request, $id)
    {
        $cita = Cita::find($id);
        $cita->atendida = 1;
        $cita->save();

        return redirect()->back()->with('success', 'Cita marcada como atendida');
    }

    public function marcarComoAtendidaa(Request $request, $id)
    {
        $cita = Cita::find($id);
        $cita->atendida = 1;
        $cita->save();
        return redirect()->back();
    }










    public function citasDelDia()
    {
        // Obtener la fecha actual en la zona horaria de Costa Rica
        $fechaActual = Carbon::now('America/Costa_Rica')->toDateString();

        // Filtrar citas del día que no han sido atendidas
        $data = Cita::whereDate('fecha', $fechaActual)
            ->where(function ($query) {
                $query->whereNull('atendida')
                    ->orWhere('atendida', '<>', 1);
            })
            ->with('cliente')
            ->get();

        return view('cita.citasDelDia', compact('data'));
    }


    // public function createDos(Request $request)
    // {
    //     // Obtener la fecha y hora de los parámetros o usar la fecha y hora actual
    //     $fecha = $request->input('fecha', date('Y-m-d'));
    //     $hora = $request->input('hora', date('H:i'));

    //     // Obtener todos los clientes
    //     $iten = Cliente::all();

    //     // Pasar datos a la vista
    //     return view('cita.createDos', compact('iten', 'fecha', 'hora'));
    // }


    // public function createDos(Request $request)
    // {
    //      // Obtener la fecha y hora de los parámetros o usar la fecha y hora actual
    //      $fecha = $request->input('fecha', date('Y-m-d'));
    //      $hora = $request->input('hora', date('H:i:s')); // Ajusta el formato de la hora a HH:MM:SS

    //      // Obtener todos los clientes
    //     $Cliente = Cliente::all();
    //     $Servicio = Servicio::all();

    //      // Pasar datos a la vista
    //     return view('cita.createDos', compact('Cliente','Servicio', 'fecha', 'hora'));
    // }

    public function createDos(Request $request)
    {
        // Obtener la fecha y hora de los parámetros o usar la fecha y hora actual
        $fecha = $request->input('fecha', date('Y-m-d'));
        $hora = $request->input('hora', date('H:i:s')); // Ajusta el formato de la hora a HH:MM:SS

        $clientes = Cliente::all(); // Obtener todos los clientes
        $servicios = Servicio::all(); // Obtener todos los servicios

        // Pasar las variables a la vista
        return view('cita.createDos', compact('clientes', 'servicios', 'fecha', 'hora'));
    }























    public function showCitaExitosa($fecha, $hora)
    {
        return view('cita.exitosa', compact('fecha', 'hora'));
    }





    public function generarPdf($fecha, $hora)
    {
        // Obtener la cita por fecha y hora
        $cita = Cita::where('fecha', $fecha)->where('hora', $hora)->first();

        // Verificar si la cita existe
        if (!$cita) {
            return redirect()->back()->with('error', 'Cita no encontrada');
        }

        // Crear el PDF
        $pdf = Pdf::loadView('cita.pdf', compact('cita'));

        // Descargar el PDF
        return $pdf->download('cita_detalle.pdf');
    }
}
